# turbo-stream

A module for down-streaming data from a selection of vendors.

[![tests](https://github.com/DirksCGM/turbo-stream/actions/workflows/tests.yml/badge.svg)](https://github.com/DirksCGM/turbo-stream/actions/workflows/tests.yml)
[![publish to pypi](https://github.com/DirksCGM/turbo-stream/actions/workflows/publish.yml/badge.svg)](https://github.com/DirksCGM/turbo-stream/actions/workflows/publish.yml)
![PyPI](https://img.shields.io/pypi/v/turbo_stream)
![PyPI - Downloads](https://img.shields.io/pypi/dm/turbo_stream)
[![CodeQL](https://github.com/DirksCGM/turbo-stream/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/DirksCGM/turbo-stream/actions/workflows/codeql-analysis.yml)

The solution is still under early stages of development, along with the wiki that can be found [Here](https://github.com/DirksCGM/turbo-stream.wiki.git).

Current support includes:
* [Google Analytics V4 Reporting Api](https://github.com/DirksCGM/turbo-stream/wiki/Google-Analytics-V4-Reporting-Api)
* [Google Search Console Api](https://github.com/DirksCGM/turbo-stream/wiki/Google-Search-Console-Api)
